@@ -146,6 +146,14 @@ class DoorLockMode(IntEnum):
     SECURED = 255
 
 
+class CodeSlotStatus(IntEnum):
+    """Enum with all (known/used) Z-Wave code slot statuses."""
+
+    AVAILABLE = 0
+    ENABLED = 1
+    DISABLED = 2
+
+
 # Depending on the Commmand Class being used by the lock, the lock state is
 # different so we need a map to track it
 LOCK_CMD_CLASS_TO_LOCKED_STATE_MAP = {
@@ -160,6 +168,13 @@ LOCK_CMD_CLASS_TO_PROPERTY_MAP = {
     CommandClass.LOCK: "locked",
 }
 
+LOCK_USERCODE_PROPERTY = "userCode"
+LOCK_USERCODE_STATUS_PROPERTY = "userIdStatus"
+ATTR_CODE_SLOT = "code_slot"
+ATTR_IN_USE = "in_use"
+ATTR_NAME = "name"
+ATTR_USERCODE = "usercode"
+
 
 # Thermostat constants
 THERMOSTAT_SETPOINT_PROPERTY = "setpoint"
