@@ -1,10 +1,17 @@
 """Provide a model for the Z-Wave JS node."""
-from typing import TYPE_CHECKING, Any, List, Optional, TypedDict, Union
+from typing import TYPE_CHECKING, Any, List, Optional, TypedDict, Union, cast
 
 from ..event import Event, EventBase
 from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
-from .value import Value, ValueDataType, get_value_id
+from .value import (
+    MetaDataType,
+    Value,
+    ValueDataType,
+    ValueMetadata,
+    ValueNotification,
+    get_value_id,
+)
 
 if TYPE_CHECKING:
     from ..client import Client
@@ -226,13 +233,13 @@ class Node(EventBase):
 
         self.emit(event.type, event.data)
 
-    async def async_set_value(self, val: Union[Value, str], new_value: Any) -> None:
+    async def async_set_value(self, val: Union[Value, str], new_value: Any) -> bool:
         """Send setValue command to Node for given value (or value_id)."""
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
             val = self.values[val]
         # the value object needs to be send to the server
-        await self.client.async_send_json_message(
+        result = await self.client.async_send_command(
             {
                 "command": "node.set_value",
                 "nodeId": self.node_id,
@@ -240,6 +247,52 @@ class Node(EventBase):
                 "value": new_value,
             }
         )
+        return cast(bool, result["success"])
+
+    async def async_refresh_info(self) -> None:
+        """Send refreshInfo command to Node."""
+        await self.client.async_send_json_message(
+            {
+                "command": "node.refresh_info",
+                "nodeId": self.node_id,
+            }
+        )
+
+    async def async_get_defined_value_ids(self) -> List[Value]:
+        """Send getDefinedValueIDs command to Node."""
+        data = await self.client.async_send_command(
+            {
+                "command": "node.get_defined_value_ids",
+                "nodeId": self.node_id,
+            }
+        )
+        return [
+            Value(self, cast(ValueDataType, valueId)) for valueId in data["valueIds"]
+        ]
+
+    async def async_get_value_metadata(self, val: Union[Value, str]) -> ValueMetadata:
+        """Send getValueMetadata command to Node."""
+        # a value may be specified as value_id or the value itself
+        if not isinstance(val, Value):
+            val = self.values[val]
+        # the value object needs to be send to the server
+        data = await self.client.async_send_command(
+            {
+                "command": "node.get_value_metadata",
+                "nodeId": self.node_id,
+                "valueId": val.data,
+            }
+        )
+        return ValueMetadata(cast(MetaDataType, data))
+
+    async def async_abort_firmware_update(self) -> None:
+        """Send abortFirmwareUpdate command to Node."""
+        await self.client.async_send_json_message(
+            {
+                "command": "node.abort_firmware_update",
+                "nodeId": self.node_id,
+            }
+        )
 
     def handle_wake_up(self, event: Event) -> None:
         """Process a node wake up event."""
@@ -291,6 +344,7 @@ class Node(EventBase):
 
     def handle_value_notification(self, event: Event) -> None:
         """Process a node value notification event."""
+        event.data["notification"] = ValueNotification.from_event(event)
 
     def handle_metadata_updated(self, event: Event) -> None:
         """Process a node metadata updated event."""
