@@ -1,4 +1,5 @@
 """Provide a model for the Z-Wave JS value."""
+from dataclasses import dataclass
 from typing import TYPE_CHECKING, Any, Dict, Optional, TypedDict, Union
 
 from ..event import Event
@@ -34,6 +35,7 @@ class ValueDataType(TypedDict, total=False):
     propertyKeyName: str
     value: Any
     metadata: MetaDataType
+    ccVersion: int
 
 
 def get_value_id(node: "Node", event_data: ValueDataType) -> str:
@@ -136,6 +138,11 @@ class Value:
         """Return commandClass."""
         return self.data["commandClass"]
 
+    @property
+    def cc_version(self) -> int:
+        """Return commandClass version."""
+        return self.data["ccVersion"]
+
     @property
     def endpoint(self) -> Optional[int]:
         """Return endpoint."""
@@ -170,3 +177,37 @@ class Value:
         """Receive an event."""
         self.data.update(event.data["args"])
         self._value = event.data["args"].get("newValue")
+
+
+@dataclass
+class ValueNotification:
+    """
+    Model for a Value Nofification message.
+
+    https://zwave-js.github.io/node-zwave-js/#/api/node?id=quotvalue-notificationquot
+    """
+
+    command_class_name: str
+    command_class: int
+    endpoint: int
+    property: str
+    value: Any
+    property_name: str
+    metadata: Optional[ValueMetadata] = None
+
+    @classmethod
+    def from_event(cls, event: Event) -> "ValueNotification":
+        """Parse event message into ValueNotification."""
+        return cls(
+            command_class_name=event.data["args"]["commandClassName"],
+            command_class=event.data["args"]["commandClass"],
+            endpoint=event.data["args"]["endpoint"],
+            property=event.data["args"]["property"],
+            value=event.data["args"].get("value"),
+            property_name=event.data["args"]["propertyName"],
+            metadata=ValueMetadata(
+                event.data["args"]["metadata"]
+                if "metadata" in event.data["args"]
+                else None
+            ),
+        )
